/* *******************
 * preferences.js
 * Easy preferences access for QuickNote  <http://quicknote.mozdev.org/>
 * (and default values too!)
 *
 * Author: Jed Brown (quicknote@jedbrown.net)
 * Contributor(s):
 *   Nickolay Ponomarev (asqueella@yahoo.com)
 *
 * Version: 0.5.8+ dev
 ******************** */

const QN_notesCount = 4;

var QN_Preferences = {
  // Note, that despite all these arrays being 0-based,
  // we actually use items [1..QN_notesCount] and do not use the 0th item.
  // Also note, that arrays are filled with their 0-th element up to notesCount.
  QN_tabFile : ['Blank'], //Path to the text files
  QN_tabName : ['Note ','Note 1','Note 2','Note 3','Note 4'], //Name of the Note Tabs

  // Variables holding user's visual customizations (per note)
  QN_padFontSize : [12],
  QN_padFontName : ['Verdana,sans-serif'],
  QN_padFontColor : ['black'],
  QN_padUserStyle : [''],
  QN_padBackColor : ['#FFFF99'],

// todo: rename these
  qnfirststart : true,
  tabtosendto : 1,
  numberoftabs : 2,
  howtopenQN : 1,
  sendToShowURL : false,
  QuickNote_saveCharset : 'UTF-8',
  QNLastTabOpened : 1,
  QN_hideButtonBox : true,
  QN_autosave : 10,


  // readPrefs()
  // Reads user preferences using nsPreferences and
  // sets up the default values for preferences that are not set yet.
  //
  // Notes: must be called when nsPreferences is accessible
  readPrefs : function() {
    // todo: use this.x as default value for this.x here
    // (after renaming these)
    this.qnfirststart = nsPreferences.getBoolPref("quicknote.firststart", true);
    this.tabtosendto = nsPreferences.getIntPref("quicknote.totabint", 1);//? was:null
    this.numberoftabs = nsPreferences.getIntPref("quicknote.numtabs", 2);
    this.howtopenQN = nsPreferences.getIntPref("quicknote.openqn", 1);

    // ? getLocalizedUnicharPref vs copyUnicharPref
    for(var i=1; i<=QN_notesCount; i++) {
      this.QN_tabFile[i] = nsPreferences.getLocalizedUnicharPref("quicknote.tab"+i+"path", this.QN_tabFile[0]);
      this.QN_padFontSize[i] = nsPreferences.getIntPref("quicknote.fontsize"+i, this.QN_padFontSize[0]);
      this.QN_padFontName[i] = nsPreferences.getLocalizedUnicharPref("quicknote.fontname"+i, this.QN_padFontName[0]);
      this.QN_padFontColor[i] = nsPreferences.getLocalizedUnicharPref("quicknote.fontcolor"+i, this.QN_padFontColor[0]);
      this.QN_padUserStyle[i] = nsPreferences.getLocalizedUnicharPref("quicknote.userstyle"+i, this.QN_padUserStyle[0]);
      this.QN_padBackColor[i] = nsPreferences.getLocalizedUnicharPref("quicknote.bgcolortab"+i, this.QN_padBackColor[0]);
      this.QN_tabName[i] = nsPreferences.getLocalizedUnicharPref("quicknote.tab"+i+"name", "Note "+i);
    }

    this.QuickNote_saveCharset = nsPreferences.getLocalizedUnicharPref("quicknote.charset", this.QuickNote_saveCharset);
    this.QNLastTabOpened = nsPreferences.getIntPref("quicknote.lasttabopen", this.QNLastTabOpened);
    this.QN_hideButtonBox = nsPreferences.getBoolPref("quicknote.hidebuttonbox", this.QN_hideButtonBox);

    //autosave options:
    // Value   Desc
    //  >0      autosave every X chars & on close
    //  =0      do not autosave while typing
    //  <0      no autosave at all -- TODO: implement save confirms on unLoad?
    this.QN_autosave = nsPreferences.getIntPref("quicknote.autosave", this.QN_autosave);
  }
};
